SquareStyle

Enum SquareStyle 

pub enum SquareStyle {
    Standard,
    Cursor,
    Word,
}
Indicates how a particular square should look. For instance, Standard might map to white, Cursor to yellow, and Word to gray.

Variants



Standard

Default styling



Cursor

The cursor is positioned on this square.



Word

The cursor is not on this square, but the word indicated by the cursor includes this square.