Enum SquareStyle
Source pub enum SquareStyle {
Standard,
Cursor,
Word,
}
Indicates how a particular square should look. For instance, Standard
might map to white, Cursor to yellow, and Word to gray.
The cursor is positioned on this square.
The cursor is not on this square, but the word indicated by the cursor includes this square.
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.